@@ -53,6 +53,8 @@ read_ima <- function(fraw, verbose = FALSE, extra) {
                               TE3 = vars$te3))
   }
   
+  if (vars$rm_oversampling) meta <- append(meta, list(fid_filt_dist = TRUE))
+  
   mrs_data <- mrs_data(data = data, ft = vars$ft, resolution = paras$res,
                        ref = paras$ref, nuc = paras$nuc,
                        freq_domain = freq_domain, affine = paras$affine,
@@ -106,12 +108,53 @@ read_ima_dyn_dir <- function(dir, extra = NULL, verbose = FALSE) {
   files <- list.files(dir, full.names = TRUE)
   if (length(files) == 0) stop("Error, read_ima_dyn_dir files not found.")
   
-  #warning("coil ordering is based on file name only.")
-  
   files <- sort(files)
   mrs_list <- lapply(files, read_mrs, format = "dicom", verbose = verbose,
                      extra = extra)
   
   mrs_data <- append_dyns(mrs_list)
-  return(mrs_data)
-}
\ No newline at end of file
+  
+  # deal with CMRR reference scans if needed
+  seq_name_upper <- toupper(mrs_data$meta$SequenceName)
+  if (startsWith(seq_name_upper, "%CUSTOMERSEQ%\\SVS_SLASER")) {
+    if (mrs_data$meta$NumberOfTransients == Ndyns(mrs_data)) {
+      return(mrs_data)
+    } else {
+      return(extract_dkd_wref_scans(mrs_data))
+    }
+  } else {
+    return(mrs_data)
+  }
+}
+
+extract_dkd_wref_scans <- function(mrs_data) {
+  
+  full_n  <- Ndyns(mrs_data)
+  metab_n <- mrs_data$meta$NumberOfTransients
+  ref_n   <- full_n - metab_n
+  metab_inds <- (ref_n / 2 + 1):(full_n - ref_n / 2)
+  metab <- get_dyns(mrs_data, metab_inds)
+  
+  ref_inds_start <- 1:(ref_n / 2)
+  ref_inds_end   <- ((full_n - ref_n / 2) + 1):full_n
+  
+  # water ecc inds
+  ref_ecc_inds <- c(ref_inds_start[1:(ref_n / 4)],
+                    ref_inds_end[1:(ref_n / 4)])
+  ref_ecc <- get_dyns(mrs_data, ref_ecc_inds)
+  ref_ecc <- set_Ntrans(ref_ecc, Ndyns(ref_ecc))
+  ref_ecc$meta$ChemicalShiftReference <- NULL
+  
+  # water scaling inds
+  ref_inds <- c(ref_inds_start[((ref_n / 4) + 1):(ref_n / 2)],
+                ref_inds_end[((ref_n / 4) + 1):(ref_n / 2)])
+  ref <- get_dyns(mrs_data, ref_inds)
+  ref <- set_Ntrans(ref, Ndyns(ref))
+  ref$meta$ChemicalShiftReference <- NULL
+  
+  out <- list(metab = metab, ref = ref, ref_ecc = ref_ecc)
+  
+  class(out) <- c("list", "mrs_data")
+  
+  return(out)
+}
